@@ -20,10 +20,8 @@ class JsonpathExpression(object):
         :return: [[key,key,value],[...]] 列表
         """
         if isinstance(response,str) and response.startswith("{"):           #判断response是不是"{}"
-            list_re = self.jsonpath_list(response=json.loads(response))          #递归，递归后返回的是该字典下的[[key,key,value],[...]] 列表
-            for d in list_re:
-                yield d                                                     #类似于 list.append(d)
-        elif isinstance(response,dict):                                     #判断response是否为字典类型
+            response = json.loads(response)
+        if isinstance(response,dict):                                       #判断response是否为字典类型
             for k,v in response.items():                                    #遍历response,取key、value值
                 if isinstance(v,dict):                                      #判断value是否为字典类型
                     list_re = self.jsonpath_list(v,re + [k])                     #递归，递归后返回的是该字典下的[[key,key,value],[...]] 列表
@@ -64,8 +62,10 @@ class JsonpathExpression(object):
         :param dict_ex_value: jsonpath_expression()返回结果
         :return:
         '''
+        if dict_ex_value is None:
+            raise Exception("提取内容为None")
+        if isinstance(response,str) and response.startswith("{"):
+            response = json.loads(response)
         for k,v in dict_ex_value.items():
-            extract_value=jsonpath.jsonpath(json.loads(response),k)[0]
-            print(f'表达式为：{k}，原有的值为：{v}，jsonpath取值为: {extract_value}')
-
-
+            extract_value=jsonpath.jsonpath(response,k)[0]
+            print(f'表达式为：{k}，原有的值为：{v}，jsonpath取值为: {extract_value}')
\ No newline at end of file
